==> portal-1.1.20-202004140543-sources.jar: com/gtis/portal/service/impl/TaskPerformerMinWorkloadFilterServiceImpl.java <==
package com.gtis.portal.service.impl;

import cn.gtmap.estateplat.service.portal.TaskPerformerFilterService;
import com.google.common.collect.Lists;
import com.gtis.config.AppConfig;
import com.gtis.plat.service.*;
import com.gtis.plat.vo.PfTaskVo;
import com.gtis.plat.vo.PfUserVo;
import com.gtis.plat.vo.PfWorkFlowDefineVo;
import com.gtis.plat.vo.PfWorkFlowInstanceVo;
import com.gtis.plat.wf.WorkFlowInfo;
import com.gtis.plat.wf.model.ActivityModel;
import com.gtis.plat.wf.model.PerformerModel;
import com.gtis.portal.entity.BdcXm;
import com.gtis.portal.service.TaskAfterTurnGeneralService;
import com.gtis.portal.service.server.AutoTurnAllTaskService;
import com.gtis.portal.service.server.AutoTurnTaskService;
import com.gtis.portal.service.server.BdcXmService;
import com.gtis.portal.support.spring.PerformanceMonitorInterceptor;
import com.gtis.portal.util.WorkFlowXml;
import com.gtis.portal.util.WorkFlowXmlUtil;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/9/21
 * @description 自动派件（转发时候按照申请类型和节点计算办件量，通过办件量进行按顺序派件）
 */
public class TaskPerformerMinWorkloadFilterServiceImpl implements TaskPerformerFilterService {
    private static final Logger log = LoggerFactory.getLogger(PerformanceMonitorInterceptor.class);

    @Autowired
    SysWorkFlowInstanceService sysWorkFlowInstanceService;
    @Autowired
    AutoTurnTaskService autoTurnTaskService;
    @Autowired
    SysUserService sysUserService;
    @Autowired
    BdcXmService bdcXmService;
    @Autowired
    WorkFlowCoreService workFlowService;
    @Resource(name = "taskPerformerMinWorkloadFilterService")
    TaskPerformerFilterService taskPerformerFilterService;
    @Autowired
    SysWorkFlowDefineService sysWorkFlowDefineService;
    @Autowired
    SysTaskService sysTaskService;
    @Resource(name = "taskAfterTurnGeneralServiceImpl")
    TaskAfterTurnGeneralService taskAfterTurnGeneralServiceImpl;
    @Autowired
    AutoTurnAllTaskService autoTurnAllTaskService;


    @Override
    public List<PfUserVo> getTaskPerformers(String wiid, String targetActivityDefinitionId, PfTaskVo sourceTask, List<PfUserVo> sourceUsers,String wdid) {
        //是否只有银行申请自动派件
        String onlyYhsq = AppConfig.getProperty("yhsq.only.autoTurnTask.enble");
        if (StringUtils.equals(onlyYhsq, "true")) {
            if (StringUtils.isNotBlank(wiid)) {
                List<BdcXm> bdcXmList = bdcXmService.getBdcXmList(wiid);
                boolean isyhsq = false;
                if (CollectionUtils.isNotEmpty(bdcXmList)) {
                    for (BdcXm bdcXm : bdcXmList) {
                        if (bdcXm != null && StringUtils.isNotBlank(bdcXm.getYhsqywh())) {
                            isyhsq = true;
                            break;
                        }
                    }
                }else
                    isyhsq=true;
                if (!isyhsq)
                    return null;
            }
        }

        //自动全局派件忽略类型
        boolean ignore = false;
        String sqlxs = AppConfig.getProperty("autoTurnAllTask.sqlx.ignore");
        if (StringUtils.isNotBlank(sqlxs)) {
            String[] sqlx = sqlxs.split(",");
            //获取当前流程的申请类型
            if (StringUtils.isNotBlank(wiid)) {
                List<BdcXm> bdcXmList = bdcXmService.getBdcXmList(wiid);
                if (CollectionUtils.isNotEmpty(bdcXmList) && sqlx.length > 0) {
                    for (int i = 0; i < bdcXmList.size(); i++) {
                        for (int j = 0; j < sqlx.length; j++) {
                            if (bdcXmList.get(i).getSqlx().equals(sqlx[j])) {
                                ignore = true;
                            }
                        }

                    }
                }
            }
        }

        PfWorkFlowInstanceVo pfWorkFlowInstanceVo = sysWorkFlowInstanceService.getWorkflowInstance(wiid);
        if (pfWorkFlowInstanceVo != null && StringUtils.isBlank(wiid))
            wdid = pfWorkFlowInstanceVo.getWorkflowDefinitionId();
        String userid = null;
        if("true".equals(AppConfig.getProperty("autoTurnAllTask.enble")) && !ignore){
            userid = autoTurnAllTaskService.getBdczdpjAllYhid(sourceUsers);
        }
        else if( "true".equals(AppConfig.getProperty("autoTurnTask.enble"))){
            //区域代码过滤（判断要转发的用户是否是该区域的）
            String autoTurnControlRegionCode = AppConfig.getProperty("autoTurnTask.control.regionCode");
            if (StringUtils.isNotBlank(autoTurnControlRegionCode)) {
                List<PfUserVo> realSourceUsers = new ArrayList<PfUserVo>();
                for (PfUserVo sourceUser : sourceUsers) {
                    if (sourceUser != null && StringUtils.isNotBlank(sourceUser.getUserId())) {
                        if(StringUtils.equals(autoTurnControlRegionCode, sysUserService.getRegionCodeByUserId(sourceUser.getUserId()))) {
                            realSourceUsers.add(sourceUser);
                        }
                    }
                }
                sourceUsers = realSourceUsers;
            }
            userid = autoTurnTaskService.getZdpjYhid(wdid, targetActivityDefinitionId, sourceUsers);
        }
        if (StringUtils.isNotBlank(userid)) {
            PfUserVo pfUserVo = sysUserService.getUserVo(userid);
            if (pfUserVo != null)
                return Lists.newArrayList(pfUserVo);
        }
        return null;
    }

    @Override
    public WorkFlowInfo createWorkFlowInstance(PfWorkFlowInstanceVo intanceVo, String userId) {
        WorkFlowInfo workFlowInfo = null;
        PfWorkFlowDefineVo pfWorkFlowDefineVo = null;
        if (intanceVo == null || StringUtils.isBlank(intanceVo.getWorkflowDefinitionId()))
            return null;
        pfWorkFlowDefineVo = sysWorkFlowDefineService.getWorkFlowDefine(intanceVo.getWorkflowDefinitionId());
        WorkFlowXml workXml = WorkFlowXmlUtil.getDefineModel(pfWorkFlowDefineVo);
        List<ActivityModel> activityModelList = workXml.getActivityList();
        ActivityModel activityModel = null;
        if (CollectionUtils.isNotEmpty(activityModelList))
            activityModel = activityModelList.get(0);

        //根据模型过滤用户
        String autoTurnTaskEnable = AppConfig.getProperty("autoTurnTask.enble");
        String autoTurnAllTaskEnable = AppConfig.getProperty("autoTurnAllTask.enble");
        if (activityModel != null && (StringUtils.equals(autoTurnTaskEnable, "true") || StringUtils.equals(autoTurnAllTaskEnable, "true"))) {
            List<PfUserVo> performerUsers = null;
            List<PfUserVo> pfUserVoList = Lists.newArrayList();
            for (PerformerModel performerModel : activityModel.getPerformerList()) {
                if (StringUtils.isNotBlank(performerModel.getUserId())) {
                    PfUserVo pfUserVo = new PfUserVo();
                    pfUserVo.setUserId(performerModel.getUserId());
                    pfUserVo.setUserName(sysUserService.getUserVo(performerModel.getUserId()).getUserName());
                    pfUserVoList.add(pfUserVo);
                }
                if (StringUtils.isNotBlank(performerModel.getRoleId())) {
                    List<PfUserVo> pfUserVoList1 = sysUserService.getUserListByRole(performerModel.getRoleId());
                    if (CollectionUtils.isNotEmpty(pfUserVoList1))
                        pfUserVoList.addAll(pfUserVoList1);
                }
                if (StringUtils.isNotBlank(performerModel.getOrganId())) {
                    List<PfUserVo> pfUserVoList1 = sysUserService.getUserListByOragn(performerModel.getOrganId());
                    if (CollectionUtils.isNotEmpty(pfUserVoList1))
                        pfUserVoList.addAll(pfUserVoList1);
                }

            }
            performerUsers = taskPerformerFilterService.getTaskPerformers(intanceVo.getWorkflowIntanceId(), activityModel.getDefineId(), null, pfUserVoList,intanceVo.getWorkflowDefinitionId());
            if (CollectionUtils.isNotEmpty(performerUsers)) {
                try {
                    workFlowInfo = workFlowService.createWorkFlowInstance(intanceVo, performerUsers.get(0).getUserId());
                } catch (Exception e) {
                    log.error(e.getMessage());
                }
            }
            else {
                try {
                    workFlowInfo = workFlowService.createWorkFlowInstance(intanceVo, userId);
                } catch (Exception e) {
                    log.error(e.getMessage());
                }
            }
            //计算工作量
            if(workFlowInfo!=null)
                taskAfterTurnGeneralServiceImpl.doWork(workFlowInfo);
        }
        return workFlowInfo;

    }

    /**
     * 创建并自动全局派件实现
     * @param intanceVo 工作流实例对象
     * @param userId 一般为自己用户id，作为自动全局人员派件为空时，转到自己
     * @return WorkFlowInfo
     * @throws Exception 抛出
     */
    public WorkFlowInfo createWorkFlowInstanceAndZdpjAll(PfWorkFlowInstanceVo intanceVo, String userId) throws Exception {
        WorkFlowInfo workFlowInfo = null;
        PfWorkFlowDefineVo pfWorkFlowDefineVo = null;
        if (intanceVo == null || StringUtils.isBlank(intanceVo.getWorkflowDefinitionId()))
            return null;
        pfWorkFlowDefineVo = sysWorkFlowDefineService.getWorkFlowDefine(intanceVo.getWorkflowDefinitionId());
        WorkFlowXml workXml = WorkFlowXmlUtil.getDefineModel(pfWorkFlowDefineVo);
        List<ActivityModel> activityModelList = workXml.getActivityList();
        ActivityModel activityModel = null;
        if (CollectionUtils.isNotEmpty(activityModelList))
            activityModel = activityModelList.get(0);

        //根据模型过滤用户
        String autoTurnAllTaskEnable = AppConfig.getProperty("autoTurnAllTask.enble");
        if (activityModel != null && StringUtils.equals(autoTurnAllTaskEnable, "true")) {
            List<PfUserVo> performerUsers = null;
            List<PfUserVo> pfUserVoList = Lists.newArrayList();
            for (PerformerModel performerModel : activityModel.getPerformerList()) {
                if (StringUtils.isNotBlank(performerModel.getUserId())) {
                    PfUserVo pfUserVo = new PfUserVo();
                    pfUserVo.setUserId(performerModel.getUserId());
                    pfUserVo.setUserName(sysUserService.getUserVo(performerModel.getUserId()).getUserName());
                    pfUserVoList.add(pfUserVo);
                }
                if (StringUtils.isNotBlank(performerModel.getRoleId())) {
                    List<PfUserVo> pfUserVoList1 = sysUserService.getUserListByRole(performerModel.getRoleId());
                    if (CollectionUtils.isNotEmpty(pfUserVoList1))
                        pfUserVoList.addAll(pfUserVoList1);
                }
                if (StringUtils.isNotBlank(performerModel.getOrganId())) {
                    List<PfUserVo> pfUserVoList1 = sysUserService.getUserListByOragn(performerModel.getOrganId());
                    if (CollectionUtils.isNotEmpty(pfUserVoList1))
                        pfUserVoList.addAll(pfUserVoList1);
                }

            }
            performerUsers = getTaskPerformersForZdpjAll(intanceVo.getWorkflowIntanceId(), activityModel.getDefineId(), null, pfUserVoList,intanceVo.getWorkflowDefinitionId());
            if (CollectionUtils.isNotEmpty(performerUsers))
                workFlowInfo = workFlowService.createWorkFlowInstance(intanceVo, performerUsers.get(0).getUserId());
            else
                workFlowInfo = workFlowService.createWorkFlowInstance(intanceVo, userId);
            //计算工作量
            if(workFlowInfo!=null)
                taskAfterTurnGeneralServiceImpl.doWork(workFlowInfo);
        }


        return workFlowInfo;
    }


    public List<PfUserVo> getTaskPerformersForZdpjAll(String wiid, String targetActivityDefinitionId, PfTaskVo sourceTask, List<PfUserVo> sourceUsers,String wdid) {
        PfWorkFlowInstanceVo pfWorkFlowInstanceVo = sysWorkFlowInstanceService.getWorkflowInstance(wiid);
        if (pfWorkFlowInstanceVo != null && StringUtils.isBlank(wiid))
            wdid = pfWorkFlowInstanceVo.getWorkflowDefinitionId();
        String userid = null;
        if( "true".equals(AppConfig.getProperty("autoTurnAllTask.enble"))){
            userid = autoTurnAllTaskService.getBdczdpjAllYhid(sourceUsers);
        }
        if (StringUtils.isNotBlank(userid)) {
            PfUserVo pfUserVo = sysUserService.getUserVo(userid);
            if (pfUserVo != null)
                return Lists.newArrayList(pfUserVo);
        }
        return null;
    }

}

==> portal-1.1.22-202011160929-sources.jar: com/gtis/portal/service/impl/TaskPerformerMinWorkloadFilterServiceImpl.java <==
package com.gtis.portal.service.impl;

import cn.gtmap.estateplat.service.portal.TaskPerformerFilterService;
import com.alibaba.fastjson.JSON;
import com.google.common.collect.Lists;
import com.gtis.config.AppConfig;
import com.gtis.plat.service.*;
import com.gtis.plat.vo.PfTaskVo;
import com.gtis.plat.vo.PfUserVo;
import com.gtis.plat.vo.PfWorkFlowDefineVo;
import com.gtis.plat.vo.PfWorkFlowInstanceVo;
import com.gtis.plat.wf.WorkFlowInfo;
import com.gtis.plat.wf.model.ActivityModel;
import com.gtis.plat.wf.model.PerformerModel;
import com.gtis.portal.entity.BdcXm;
import com.gtis.portal.entity.BdcZdpjjlAll;
import com.gtis.portal.service.TaskAfterTurnGeneralService;
import com.gtis.portal.service.server.AutoTurnAllTaskService;
import com.gtis.portal.service.server.AutoTurnTaskService;
import com.gtis.portal.service.server.BdcXmService;
import com.gtis.portal.support.spring.PerformanceMonitorInterceptor;
import com.gtis.portal.util.WorkFlowXml;
import com.gtis.portal.util.WorkFlowXmlUtil;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/9/21
 * @description 自动派件（转发时候按照申请类型和节点计算办件量，通过办件量进行按顺序派件）
 */
public class TaskPerformerMinWorkloadFilterServiceImpl implements TaskPerformerFilterService {
    private static final Logger log = LoggerFactory.getLogger(PerformanceMonitorInterceptor.class);

    @Autowired
    SysWorkFlowInstanceService sysWorkFlowInstanceService;
    @Autowired
    AutoTurnTaskService autoTurnTaskService;
    @Autowired
    SysUserService sysUserService;
    @Autowired
    BdcXmService bdcXmService;
    @Autowired
    WorkFlowCoreService workFlowService;
    @Resource(name = "taskPerformerMinWorkloadFilterService")
    TaskPerformerFilterService taskPerformerFilterService;
    @Autowired
    SysWorkFlowDefineService sysWorkFlowDefineService;
    @Autowired
    SysTaskService sysTaskService;
    @Resource(name = "taskAfterTurnGeneralServiceImpl")
    TaskAfterTurnGeneralService taskAfterTurnGeneralServiceImpl;
    @Autowired
    AutoTurnAllTaskService autoTurnAllTaskService;


    @Override
    public List<PfUserVo> getTaskPerformers(String wiid, String targetActivityDefinitionId, PfTaskVo sourceTask, List<PfUserVo> sourceUsers,String wdid) {
        //是否只有银行申请自动派件
        String onlyYhsq = AppConfig.getProperty("yhsq.only.autoTurnTask.enble");
        log.info("转发节点用户："+ JSON.toJSONString(sourceUsers));
        if (StringUtils.equals(onlyYhsq, "true")) {
            if (StringUtils.isNotBlank(wiid)) {
                List<BdcXm> bdcXmList = bdcXmService.getBdcXmList(wiid);
                boolean isyhsq = false;
                if (CollectionUtils.isNotEmpty(bdcXmList)) {
                    for (BdcXm bdcXm : bdcXmList) {
                        if (bdcXm != null && StringUtils.isNotBlank(bdcXm.getYhsqywh())) {
                            isyhsq = true;
                            break;
                        }
                    }
                }else
                    isyhsq=true;
                if (!isyhsq)
                    return null;
            }
        }

        //自动全局派件忽略类型
        boolean ignore = false;
        String sqlxs = AppConfig.getProperty("autoTurnAllTask.sqlx.ignore");
        if (StringUtils.isNotBlank(sqlxs)) {
            String[] sqlx = sqlxs.split(",");
            //获取当前流程的申请类型
            if (StringUtils.isNotBlank(wiid)) {
                List<BdcXm> bdcXmList = bdcXmService.getBdcXmList(wiid);
                if (CollectionUtils.isNotEmpty(bdcXmList) && sqlx.length > 0) {
                    for (int i = 0; i < bdcXmList.size(); i++) {
                        for (int j = 0; j < sqlx.length; j++) {
                            if (bdcXmList.get(i).getSqlx().equals(sqlx[j])) {
                                ignore = true;
                            }
                        }

                    }
                }
            }
        }

        PfWorkFlowInstanceVo pfWorkFlowInstanceVo = sysWorkFlowInstanceService.getWorkflowInstance(wiid);
        if (pfWorkFlowInstanceVo != null && StringUtils.isBlank(wiid))
            wdid = pfWorkFlowInstanceVo.getWorkflowDefinitionId();
        String userid = null;
        if ("true".equals(AppConfig.getProperty("autoTurnAllTask.enble")) && !ignore) {
            if (AppConfig.getBooleanProperty("autoTurnTask.onlyPjsx.enable")) {
                userid = autoTurnTaskService.getLoopBdcZdpjjlAllYhId(sourceUsers);//循环派件
            } else {
                userid = autoTurnAllTaskService.getBdczdpjAllYhid(sourceUsers);
            }
        } else if( "true".equals(AppConfig.getProperty("autoTurnTask.enble"))){
            //区域代码过滤（判断要转发的用户是否是该区域的）
            String autoTurnControlRegionCode = AppConfig.getProperty("autoTurnTask.control.regionCode");
            if (StringUtils.isNotBlank(autoTurnControlRegionCode)) {
                List<PfUserVo> realSourceUsers = new ArrayList<PfUserVo>();
                for (PfUserVo sourceUser : sourceUsers) {
                    if (sourceUser != null && StringUtils.isNotBlank(sourceUser.getUserId())) {
                        if(StringUtils.equals(autoTurnControlRegionCode, sysUserService.getRegionCodeByUserId(sourceUser.getUserId()))) {
                            realSourceUsers.add(sourceUser);
                        }
                    }
                }
                sourceUsers = realSourceUsers;
            }
            if (AppConfig.getBooleanProperty("autoTurnTask.onlyPjsx.enable")) {
                userid = autoTurnTaskService.getLoopBdcZdpjjlYhId(wdid, targetActivityDefinitionId,sourceUsers);//循环派件
            } else {
                userid = autoTurnTaskService.getZdpjYhid(wdid, targetActivityDefinitionId, sourceUsers);
            }
        }
        if (StringUtils.isNotBlank(userid)) {
            PfUserVo pfUserVo = sysUserService.getUserVo(userid);
            log.info("最终转发用户:"+JSON.toJSONString(pfUserVo));
            if (pfUserVo != null)
                return Lists.newArrayList(pfUserVo);
        }
        return null;
    }

    @Override
    public WorkFlowInfo createWorkFlowInstance(PfWorkFlowInstanceVo intanceVo, String userId) {
        WorkFlowInfo workFlowInfo = null;
        PfWorkFlowDefineVo pfWorkFlowDefineVo = null;
        if (intanceVo == null || StringUtils.isBlank(intanceVo.getWorkflowDefinitionId()))
            return null;
        pfWorkFlowDefineVo = sysWorkFlowDefineService.getWorkFlowDefine(intanceVo.getWorkflowDefinitionId());
        WorkFlowXml workXml = WorkFlowXmlUtil.getDefineModel(pfWorkFlowDefineVo);
        List<ActivityModel> activityModelList = workXml.getActivityList();
        ActivityModel activityModel = null;
        if (CollectionUtils.isNotEmpty(activityModelList))
            activityModel = activityModelList.get(0);

        //根据模型过滤用户
        String autoTurnTaskEnable = AppConfig.getProperty("autoTurnTask.enble");
        String autoTurnAllTaskEnable = AppConfig.getProperty("autoTurnAllTask.enble");
        if (activityModel != null && (StringUtils.equals(autoTurnTaskEnable, "true") || StringUtils.equals(autoTurnAllTaskEnable, "true"))) {
            List<PfUserVo> performerUsers = null;
            List<PfUserVo> pfUserVoList = Lists.newArrayList();
            for (PerformerModel performerModel : activityModel.getPerformerList()) {
                if (StringUtils.isNotBlank(performerModel.getUserId())) {
                    PfUserVo pfUserVo = new PfUserVo();
                    pfUserVo.setUserId(performerModel.getUserId());
                    pfUserVo.setUserName(sysUserService.getUserVo(performerModel.getUserId()).getUserName());
                    pfUserVoList.add(pfUserVo);
                }
                if (StringUtils.isNotBlank(performerModel.getRoleId())) {
                    List<PfUserVo> pfUserVoList1 = sysUserService.getUserListByRole(performerModel.getRoleId());
                    if (CollectionUtils.isNotEmpty(pfUserVoList1))
                        pfUserVoList.addAll(pfUserVoList1);
                }
                if (StringUtils.isNotBlank(performerModel.getOrganId())) {
                    List<PfUserVo> pfUserVoList1 = sysUserService.getUserListByOragn(performerModel.getOrganId());
                    if (CollectionUtils.isNotEmpty(pfUserVoList1))
                        pfUserVoList.addAll(pfUserVoList1);
                }

            }
            performerUsers = taskPerformerFilterService.getTaskPerformers(intanceVo.getWorkflowIntanceId(), activityModel.getDefineId(), null, pfUserVoList,intanceVo.getWorkflowDefinitionId());
            if (CollectionUtils.isNotEmpty(performerUsers)) {
                try {
                    workFlowInfo = workFlowService.createWorkFlowInstance(intanceVo, performerUsers.get(0).getUserId());
                } catch (Exception e) {
                    log.error(e.getMessage());
                }
            }
            else {
                try {
                    workFlowInfo = workFlowService.createWorkFlowInstance(intanceVo, userId);
                } catch (Exception e) {
                    log.error(e.getMessage());
                }
            }
            //计算工作量
            if(workFlowInfo!=null)
                taskAfterTurnGeneralServiceImpl.doWork(workFlowInfo);
        }
        return workFlowInfo;

    }

    /**
     * 创建并自动全局派件实现
     * @param intanceVo 工作流实例对象
     * @param userId 一般为自己用户id，作为自动全局人员派件为空时，转到自己
     * @return WorkFlowInfo
     * @throws Exception 抛出
     */
    public WorkFlowInfo createWorkFlowInstanceAndZdpjAll(PfWorkFlowInstanceVo intanceVo, String userId) throws Exception {
        WorkFlowInfo workFlowInfo = null;
        PfWorkFlowDefineVo pfWorkFlowDefineVo = null;
        if (intanceVo == null || StringUtils.isBlank(intanceVo.getWorkflowDefinitionId()))
            return null;
        pfWorkFlowDefineVo = sysWorkFlowDefineService.getWorkFlowDefine(intanceVo.getWorkflowDefinitionId());
        WorkFlowXml workXml = WorkFlowXmlUtil.getDefineModel(pfWorkFlowDefineVo);
        List<ActivityModel> activityModelList = workXml.getActivityList();
        ActivityModel activityModel = null;
        if (CollectionUtils.isNotEmpty(activityModelList))
            activityModel = activityModelList.get(0);

        //根据模型过滤用户
        String autoTurnAllTaskEnable = AppConfig.getProperty("autoTurnAllTask.enble");
        if (activityModel != null && StringUtils.equals(autoTurnAllTaskEnable, "true")) {
            List<PfUserVo> performerUsers = null;
            List<PfUserVo> pfUserVoList = Lists.newArrayList();
            for (PerformerModel performerModel : activityModel.getPerformerList()) {
                if (StringUtils.isNotBlank(performerModel.getUserId())) {
                    PfUserVo pfUserVo = new PfUserVo();
                    pfUserVo.setUserId(performerModel.getUserId());
                    pfUserVo.setUserName(sysUserService.getUserVo(performerModel.getUserId()).getUserName());
                    pfUserVoList.add(pfUserVo);
                }
                if (StringUtils.isNotBlank(performerModel.getRoleId())) {
                    List<PfUserVo> pfUserVoList1 = sysUserService.getUserListByRole(performerModel.getRoleId());
                    if (CollectionUtils.isNotEmpty(pfUserVoList1))
                        pfUserVoList.addAll(pfUserVoList1);
                }
                if (StringUtils.isNotBlank(performerModel.getOrganId())) {
                    List<PfUserVo> pfUserVoList1 = sysUserService.getUserListByOragn(performerModel.getOrganId());
                    if (CollectionUtils.isNotEmpty(pfUserVoList1))
                        pfUserVoList.addAll(pfUserVoList1);
                }

            }
            performerUsers = getTaskPerformersForZdpjAll(intanceVo.getWorkflowIntanceId(), activityModel.getDefineId(), null, pfUserVoList,intanceVo.getWorkflowDefinitionId());
            if (CollectionUtils.isNotEmpty(performerUsers))
                workFlowInfo = workFlowService.createWorkFlowInstance(intanceVo, performerUsers.get(0).getUserId());
            else
                workFlowInfo = workFlowService.createWorkFlowInstance(intanceVo, userId);
            //计算工作量
            if(workFlowInfo!=null)
                taskAfterTurnGeneralServiceImpl.doWork(workFlowInfo);
        }


        return workFlowInfo;
    }


    public List<PfUserVo> getTaskPerformersForZdpjAll(String wiid, String targetActivityDefinitionId, PfTaskVo sourceTask, List<PfUserVo> sourceUsers,String wdid) {
        PfWorkFlowInstanceVo pfWorkFlowInstanceVo = sysWorkFlowInstanceService.getWorkflowInstance(wiid);
        if (pfWorkFlowInstanceVo != null && StringUtils.isBlank(wiid))
            wdid = pfWorkFlowInstanceVo.getWorkflowDefinitionId();
        String userid = null;
        if( "true".equals(AppConfig.getProperty("autoTurnAllTask.enble"))){
            userid = autoTurnAllTaskService.getBdczdpjAllYhid(sourceUsers);
        }
        if (StringUtils.isNotBlank(userid)) {
            PfUserVo pfUserVo = sysUserService.getUserVo(userid);
            if (pfUserVo != null)
                return Lists.newArrayList(pfUserVo);
        }
        return null;
    }

}
